@@ -7,7 +7,7 @@ import warnings
 
 import numpy as np
 import pandas as pd
-from pytorch_lightning.core.lightning import LightningModule
+from pytorch_lightning import LightningModule
 import torch
 
 from collie.interactions import (ApproximateNegativeSamplingInteractionsDataLoader,
@@ -268,7 +268,11 @@ class BasePipeline(LightningModule, metaclass=ABCMeta):
 
     def _move_any_external_data_to_device(self):
         """Code for ensuring all side-data is put onto the model's device before training."""
-        pass
+        if self.hparams.metadata_for_loss is not None:
+            self.hparams.metadata_for_loss = {
+                k: v.to(self.device)
+                for k, v in self.hparams.metadata_for_loss.items()
+            }
 
     def _configure_loss(self) -> None:
         # set up loss function
@@ -354,11 +358,6 @@ class BasePipeline(LightningModule, metaclass=ABCMeta):
         exception of the learning rate, which will be set to ``self.hparams.bias_lr``.
 
         """
-        # since this is the only function that is called before each ``trainer.fit`` call, we will
-        # also take this time to ensure any external data a model might rely on has been properly
-        # moved to the device before training
-        self._move_any_external_data_to_device()
-
         if self.bias_optimizer is not None:
             if self.bias_optimizer == 'infer':
                 self.bias_optimizer = self.optimizer
@@ -479,12 +478,21 @@ class BasePipeline(LightningModule, metaclass=ABCMeta):
 
         return optimizer_parameters
 
+    def on_fit_start(self) -> None:
+        """
+        Method that runs at the very beginning of the fit process.
+
+        This method will be called after ``configure_optimizers``.
+
+        """
+        self._move_any_external_data_to_device()
+
     def train_dataloader(self) -> Union[ApproximateNegativeSamplingInteractionsDataLoader,
                                         InteractionsDataLoader]:
         """
         Method that sets up training data as a PyTorch DataLoader.
 
-        This method will be called after ``configure_optimizers``.
+        This method will be called after ``on_fit_start``.
 
         """
         return self.train_loader
