@@ -199,11 +199,6 @@ class MultiStagePipeline(BasePipeline, metaclass=ABCMeta):
         ``self.hparams.optimizer_config_list``.
 
         """
-        # since this is the only function that is called before each ``trainer.fit`` call, we will
-        # also take this time to ensure any external data a model might rely on has been properly
-        # moved to the device before training
-        self._move_any_external_data_to_device()
-
         optimizer_config_list = [
             self._get_optimizer(self.optimizer, optimizer_config=optimizer_config)
             for optimizer_config in self.hparams.optimizer_config_list
